Development Documentation
========================

This section contains documentation for developers working on the ExactCIs package.

.. toctree::
   :maxdepth: 2
   :caption: Development Guide:

   architecture
   methodology
   blaker_correction_guide
   performance_optimization
   
.. toctree::
   :maxdepth: 2
   :caption: Analysis & Validation:

   literature/index
   analysis/index
   method_comparison
   implementation_comparison
   validation_summary
   test_monitoring